# RgbColor

An RGB color.

**Type:** object

## Properties

- **red** (number): The red component of the color, from 0.0 to 1.0.
- **green** (number): The green component of the color, from 0.0 to 1.0.
- **blue** (number): The blue component of the color, from 0.0 to 1.0.
